==> haskell-binary-orphans-0.1.8.0-53-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-3AL88fxeaSuBtZthT9tx9v
key: binary-orphans-0.1.8.0-3AL88fxeaSuBtZthT9tx9v
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
abi: 9dd933de6286f47ac09af919f9eb4250
exposed: True
exposed-modules:
    Data.Binary.Orphans
import-dirs: /usr/lib/ghc-8.4.3/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-3AL88fxeaSuBtZthT9tx9v
depends:
    base-4.11.1.0 aeson-1.4.0.0-2fzGzKiyJUwJpJnaq3iWXS binary-0.8.5.1
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    text-binary-0.2.1.1-7bwUglmU72QFRTrmWpWnKz
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.0.0-2fzGzKiyJUwJpJnaq3iWXS=1a1b9e384095a5a09c623b25305bd94d
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             scientific-0.3.6.2-KcBBbCjUUZZKnRSUL2OTul=67146f6b2fe2f883da537f78817eb0dd
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             text-binary-0.2.1.1-7bwUglmU72QFRTrmWpWnKz=264e1316fae1f5a6091a3cc97e76c942
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-orphans-0.1.8.0-54-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-binary-orphans.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-orphans
version: 0.1.8.0
id: binary-orphans-0.1.8.0-4pJxE9xKSYjHqfNpoT2Kua
key: binary-orphans-0.1.8.0-4pJxE9xKSYjHqfNpoT2Kua
license: BSD-3-Clause
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
author: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-orphans#readme
synopsis: Orphan instances for binary
description:
    `binary-orphans` defines orphan instances for types in some popular packages.
category: Web
abi: 23624d83cf9f5210c19a761a70caea61
exposed: True
exposed-modules:
    Data.Binary.Orphans
import-dirs: /usr/lib/ghc-8.4.3/site-local/binary-orphans-0.1.8.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/binary-orphans-0.1.8.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/binary-orphans-0.1.8.0
hs-libraries: HSbinary-orphans-0.1.8.0-4pJxE9xKSYjHqfNpoT2Kua
depends:
    base-4.11.1.0 aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh binary-0.8.5.1
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    text-binary-0.2.1.1-7bwUglmU72QFRTrmWpWnKz
    vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             aeson-1.4.0.0-CakggGCi8AH730RFzdp4vh=7bc5561c9bccdf225964aec1dc0920a0
             binary-0.8.5.1=0c28e4e382bf1405fd468e0d2a2b58e5
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0f14342a1ffe8710d31657335cf81134
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             unordered-containers-0.2.9.0-KfM11vwfv9j3BnvMvjdQDd=4d1dd6bd73dbf55dc13ef767664a6e82
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             text-binary-0.2.1.1-7bwUglmU72QFRTrmWpWnKz=264e1316fae1f5a6091a3cc97e76c942
             vector-binary-instances-0.2.4-DozAADK9jE3EJNfe3MCYFT=a05eda2525e053256908ffd96812f0de
haddock-interfaces: /usr/share/doc/haskell-binary-orphans/html/binary-orphans.haddock
haddock-html: /usr/share/doc/haskell-binary-orphans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
